==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-brightness/translations/lxqt-config-brightness_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Fényerő beállítások</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Háttérvilágítás és fényerő beállítás:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Nyílbillentyűkkel változtatható.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>A változtatáshoz megerősítés kell</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>Fényerő beállítás megváltozott</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Megerősítés kell. Jó a beállítás?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Kimenet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-config_0.15.0.orig.tar.xz: lxqt-config-0.15.0/lxqt-config-brightness/translations/lxqt-config-brightness_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Fényerő beállítások</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Háttérvilágítás és fényerő beállítás:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Nyílbillentyűkkel változtatható.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>A változtatáshoz megerősítés szükséges</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>Fényerő beállítás megváltozott</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Megerősítés szükséges. Jó a beállítás?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Kimenet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation>Jobb kattintás a visszaállításhoz</translation>
    </message>
</context>
</TS>
